MarketStatus

Enum MarketStatus 

#[repr(u64)]
pub enum MarketStatus { Uninitialized = 0, Active = 1, PostOnly = 2, Paused = 3, Closed = 4, Tombstoned = 5, }

Variants



Uninitialized = 0



Active = 1

All new orders, placements, and reductions are accepted. Crossing the spread is permissionless.



PostOnly = 2

Only places, reductions and withdrawals are accepted.



Paused = 3

Only reductions and withdrawals are accepted.



Closed = 4

Only reductions and withdrawals are accepted. The market authority can forcibly cancel all orders.



Tombstoned = 5

Used to signal the market to be deleted. Can only be called in a Closed state where all orders and traders are removed from the book

Implementations