pub struct WithdrawParams {
pub quote_lots_to_withdraw: Option<u64>,
pub base_lots_to_withdraw: Option<u64>,
}Fields
quote_lots_to_withdraw: Option<u64>base_lots_to_withdraw: Option<u64>Trait Implementations
Sourceimpl BorshDeserialize for WithdrawParams
impl BorshDeserialize for WithdrawParams
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for WithdrawParams
impl BorshSerialize for WithdrawParams
Sourceimpl Clone for WithdrawParams
impl Clone for WithdrawParams
Sourcefn clone(&self) -> WithdrawParams
fn clone(&self) -> WithdrawParams
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for WithdrawParams
Sourceimpl Debug for WithdrawParams
impl Debug for WithdrawParams
Sourceimpl Default for WithdrawParams
impl Default for WithdrawParams
Sourcefn default() -> WithdrawParams
fn default() -> WithdrawParams
Returns the “default value” for a type. Read more
impl Eq for WithdrawParams
Sourceimpl PartialEq for WithdrawParams
impl PartialEq for WithdrawParams
Sourcefn eq(&self, other: &WithdrawParams) -> bool
fn eq(&self, other: &WithdrawParams) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for WithdrawParams